@@ -1,4 +1,4 @@
-// $Id: ArcGraphE.h,v 1.6 1998/03/25 12:42:15 zeller Exp $ -*- C++ -*-
+// $Id: ArcGraphE.h,v 1.8 1998/08/03 11:15:28 zeller Exp $ -*- C++ -*-
 // Arc edges
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
@@ -55,10 +55,16 @@ protected:
     static bool center(const BoxPoint& p1, const BoxPoint& p2, 
 		       const BoxPoint& p3, double& x, double& y);
 
+    // Joint function for drawing and printing
+    void makeLine(Widget w,
+		  const BoxRegion& exposed,
+		  ostream& os,
+		  const GraphGC& gc) const;
+
 public:
     // Constructor
-    ArcGraphEdge(GraphNode *from, GraphNode *to)
-	: LineGraphEdge(from, to)
+    ArcGraphEdge(GraphNode *from, GraphNode *to, EdgeAnnotation *ann = 0)
+	: LineGraphEdge(from, to, ann)
     {}
 
     // Destructor
