@@ -1,4 +1,4 @@
-// $Id: DispBuffer.h,v 1.8 1998/03/25 12:42:55 zeller Exp $
+// $Id: DispBuffer.h,v 1.8.6.1 1998/12/06 12:59:18 zeller Exp $
 // Filter display information from GDB output
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -66,6 +66,10 @@ public:
 
     // Were there any displays in the last output?
     bool displays_found () const { return display_buffer != ""; }
+    bool partial_displays_found () const
+    {
+	return !displays_found() && already_read == DisplayPart;
+    }
 
     // Return any displays found
     string get_displays () const { return display_buffer; }
