@@ -1,5 +1,5 @@
-// $Id: DispValueA.h,v 1.2 1998/03/25 12:43:01 zeller Exp $ -*- C++ -*-
-//
+// $Id: DispValueA.h,v 1.3 1998/08/05 11:17:18 zeller Exp $ -*- C++ -*-
+// An array of DispValues
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
 // Written by Andreas Zeller <zeller@ips.cs.tu-bs.de>.
@@ -33,11 +33,12 @@
 #pragma interface
 #endif
 
-#include "DynArray.h"
-#include "DispValue.h"
+#include "VarArray.h"
+
+class DispValue;
 
 // An array of disp values
-typedef DynArray<DispValue*> DispValueArray;
+typedef VarArray<DispValue *> DispValueArray;
 
 #endif // _DDD_DispValueArray_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
