@@ -1,4 +1,4 @@
-// $Id: IntIntAA.h,v 1.5 1998/03/25 12:43:29 zeller Exp $ -*- C++ -*-
+// $Id: IntIntAA.h,v 1.6 1998/08/01 13:14:17 zeller Exp $ -*- C++ -*-
 // Assoc<int, VarArray<int> > and Assoc<string, VarArray<int> >.
 
 // Copyright (C) 1996 Technische Universitaet Braunschweig, Germany.
@@ -43,5 +43,10 @@ typedef AssocIter<int, VarIntArray> IntIntArrayAssocIter;
 typedef Assoc<string, VarIntArray> StringIntArrayAssoc;
 typedef AssocIter<string, VarIntArray> StringIntArrayAssocIter;
 
+typedef VarArray<IntArray> IntArrayArray;
+
+typedef Assoc<string, IntArrayArray> StringIntArrayArrayAssoc;
+typedef AssocIter<string, IntArrayArray> StringIntArrayArrayAssocIter;
+
 #endif // _DDD_IntIntArrayAssoc_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
