@@ -1,4 +1,4 @@
-// $Id: LineGraphE.h,v 1.15 1998/03/25 12:43:33 zeller Exp $
+// $Id: LineGraphE.h,v 1.19 1998/08/03 08:31:00 zeller Exp $
 // LineGraphEdge class: GraphEdge with drawing capabilities
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -33,9 +33,10 @@
 #pragma interface
 #endif
 
-
 #include "GraphEdge.h"
 #include "Box.h"
+#include "EdgeA.h"
+#include "explicit.h"
 
 enum Side { North = 1, South = 2, East = 4, West = 8 };
 
@@ -43,6 +44,9 @@ class LineGraphEdge: public GraphEdge {
 public:
     DECLARE_TYPE_INFO
 
+private:
+    EdgeAnnotation *_annotation; // The annotation to use
+
 protected:
     // Find line from region B1 centered around C1 to region B2 centered
     // around C2.  Resulting line shall be drawn from P1 to P2.
@@ -73,10 +77,12 @@ protected:
 			       const BoxPoint& pos,
 			       double alpha) const;
 
-    // Copy Constructor
-    LineGraphEdge(const LineGraphEdge &edge):
-	GraphEdge(edge)
-    {}
+    // Print self edge.
+    virtual void printSelf(ostream& os, const GraphGC &gc) const;
+
+    // Find annotation position.
+    virtual BoxPoint annotationPosition(const GraphGC &gc) const;
+
 
 private:
     // Clip point P to side SIDE of region B.
@@ -94,13 +100,38 @@ private:
 
 public:
     // Constructor
-    LineGraphEdge(GraphNode *f, GraphNode *t):
-	GraphEdge(f, t)
+    LineGraphEdge(GraphNode *f, GraphNode *t, EdgeAnnotation *ann = 0):
+	GraphEdge(f, t), _annotation(ann)
     {}
 
     // Destructor
-    virtual ~LineGraphEdge() {}
+    virtual ~LineGraphEdge()
+    {
+	delete _annotation;
+    }
 
+    // Resources
+    void set_annotation(EdgeAnnotation *a)
+    {
+	if (a != _annotation)
+	{
+	    delete _annotation;
+	    _annotation = a;
+	}
+    }
+
+    EdgeAnnotation *annotation() const { return _annotation; }
+
+protected:
+    // Copy Constructor
+    LineGraphEdge(const LineGraphEdge &edge):
+	GraphEdge(edge), _annotation(0)
+    {
+	if (edge.annotation() != 0)
+	    set_annotation(edge.annotation()->dup());
+    }
+
+public:
     // Printing
     void _print(ostream& os, const GraphGC &gc) const;
 
@@ -108,6 +139,9 @@ public:
     {
 	return new LineGraphEdge(*this);
     }
+
+    // Region occupied by edge - if none, BoxRegion()
+    virtual BoxRegion region(const GraphGC&) const;
 };
 
 #endif // _DDD_LineGraphEdge_h
