@@ -1,4 +1,4 @@
-// $Id: SmartC.h,v 1.1 1998/05/25 11:19:36 zeller Exp $ -*- C++ -*-
+// $Id: SmartC.h,v 1.2 1998/09/22 11:31:32 zeller Exp $ -*- C++ -*-
 // `smart' string comparison
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -42,7 +42,7 @@ extern int smart_compare(const char *s1, const char *s2);
 // Sort array S, using smart_compare
 extern void smart_sort(StringArray& s);
 extern void smart_sort(char *a[], int size);
-extern void smart_sort(string a[], int size);
+extern void smart_sort(string *a, int size);
 
 // Remove adjacent duplicates in A
 extern void uniq(StringArray& a);
