@@ -1,4 +1,4 @@
-// $Id: comm-manag.h,v 1.24 1998/10/28 14:15:20 zeller Exp $
+// $Id: comm-manag.h,v 1.24.4.1 1998/12/06 15:36:19 zeller Exp $
 // GDB communication manager.
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -76,6 +76,9 @@ void internal_command(const string& command, OQCProc callback, void *data,
 string internal_command(const string& command);
 bool is_internal_command(const string& command);
 
+// Return GDB output that has not been echoed yet
+string buffered_gdb_output();
+
 // True if the debuggee is running
 extern bool debuggee_running;
 
