@@ -1,4 +1,4 @@
-// $Id: filetype.h,v 1.10 1998/03/25 12:45:53 zeller Exp $ -*- C++ -*-
+// $Id: filetype.h,v 1.13 1998/11/10 18:21:51 zeller Exp $ -*- C++ -*-
 // Determine file type
 
 // Copyright (C) 1995 Technische Universitaet Braunschweig, Germany.
@@ -31,10 +31,14 @@
 
 #include "bool.h"
 #include "strclass.h"
+#include <time.h>		// time_t
 
 // True if FILE_NAME is a regular file
 bool is_regular_file(const string& file_name);
 
+// True if FILE_NAME contains non-TEXT characters
+bool is_binary_file(const string& file_name);
+
 // True if FILE_NAME is an executable binary file
 bool is_exec_file(const string& file_name);
 
@@ -53,8 +57,11 @@ bool is_postscript_file(const string& file_name);
 // True if FILE_NAME is a FIG file
 bool is_fig_file(const string& file_name);
 
-// True if FILE_NAME is a X Window Dump file
-bool is_xwd_file(const string& file_name);
+// True if FILE_NAME is a PERL file
+bool is_perl_file(const string& file_name);
+
+// True if FILE_NAME is a PYTHON file
+bool is_python_file(const string& file_name);
 
 // True if FILE_NAME is a directory
 bool is_directory(const string& file_name);
@@ -62,5 +69,8 @@ bool is_directory(const string& file_name);
 // Return full file name of COMMAND
 string cmd_file(const string& command);
 
+// Return last modification time of FILE_NAME
+time_t last_modification_time(const string& file_name);
+
 #endif // _DDD_filetype_h
 // DON'T ADD ANYTHING BEHIND THIS #endif
