@@ -1,4 +1,4 @@
-// $Id: java.h,v 1.3 1998/04/22 13:43:12 zeller Exp $ -*- C++ -*-
+// $Id: java.h,v 1.5 1998/06/30 16:44:42 zeller Exp $ -*- C++ -*-
 // Find Java class
 
 // Copyright (C) 1998 Technische Universitaet Braunschweig, Germany.
@@ -35,18 +35,14 @@
 
 #include "StringA.h"
 
-// Suffixes for Java sources and classes
-#define JAVA_SRC_SUFFIX   ".java"
-#define JAVA_CLASS_SUFFIX ".class"
-
-// Store all classes matching MASK in CLASSES_LIST
-void get_java_classes(StringArray& classes_list, 
-		      const string& mask = "*" JAVA_SRC_SUFFIX);
+// Store all classes in current use path in CLASSES_LIST.  If
+// WITH_SOURCE_ONLY is set, consider only classes with loadable sources.
+void get_java_classes(StringArray& classes_list, bool with_source_only = true);
 
 // Return source file of CLASS_NAME; "" if none
 string java_class_file(const string& class_name, bool search_classes = true);
 
-// Remove `.java' suffix from S
+// Remove `.java' and `.class' suffix from S
 void strip_java_suffix(string& s);
 
 // Return the position of CLASS_NAME definition in TEXT; -1 if none
