@@ -1,4 +1,4 @@
-// $Id: regexps.h,v 1.17 1998/06/07 11:09:39 zeller Exp $ -*- C++ -*-
+// $Id: regexps.h,v 1.23 1998/10/23 11:47:06 zeller Exp $ -*- C++ -*-
 // Regular expressions used in DDD
 
 // Copyright (C) 1997 Technische Universitaet Braunschweig, Germany.
@@ -121,6 +121,9 @@ extern const regex rxoptions;
 extern const regex rxout_of_range;
 extern const regex rxpath_cmd;
 extern const regex rxpc;
+extern const regex rxperlpos;
+extern const regex rxperlprompt;
+extern const regex rxperlref;
 extern const regex rxprocess1;
 extern const regex rxprocess2;
 extern const regex rxprompt;
@@ -136,6 +139,7 @@ extern const regex rxsemicolon_and_brace;
 extern const regex rxsep;
 extern const regex rxset1_cmd;
 extern const regex rxset2_cmd;
+extern const regex rxset3_cmd;
 extern const regex rxset_args_cmd;
 extern const regex rxsetting_cmd;
 extern const regex rxsimple;
@@ -143,11 +147,12 @@ extern const regex rxsingle_display_cmd;
 extern const regex rxspace;
 extern const regex rxstopped_addr;
 extern const regex rxstopped_func;
-extern const regex rxstr_or_cl_begin;
-extern const regex rxstr_or_cl_end;
+extern const regex rxstruct_begin;
+extern const regex rxstruct_end;
 extern const regex rxstruct_keyword_begin;
 extern const regex rxterminated;
 extern const regex rxthread_cmd;
+extern const regex rxdbx_baseclass;
 extern const regex rxundisplay;
 extern const regex rxup_cmd;
 extern const regex rxuppercase;
